@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import with_statement
 
-import collections
 import contextlib
 import glob
 import json
@@ -22,8 +21,10 @@ from six import StringIO, b, string_types, text_type
 from werkzeug.test import Client
 from werkzeug.wrappers import Response
 
+import pysassc
 import sass
 import sassc
+from sassutils._compat import collections_abc
 from sassutils.builder import Manifest, build_directory
 from sassutils.wsgi import SassMiddleware
 
@@ -126,6 +127,12 @@ body p {
 '''
 
 
+@pytest.fixture(autouse=True)
+def no_warnings(recwarn):
+    yield
+    assert len(recwarn) == 0
+
+
 class BaseTestCase(unittest.TestCase):
 
     def assert_source_map_equal(self, expected, actual):
@@ -141,7 +148,7 @@ class BaseTestCase(unittest.TestCase):
                 tree = json.load(f)
             except ValueError as e:  # pragma: no cover
                 f.seek(0)
-                msg = '{0!s}\n\n{1}:\n\n{2}'.format(e, filename, f.read())
+                msg = '{!s}\n\n{}:\n\n{}'.format(e, filename, f.read())
                 raise ValueError(msg)
         self.assert_source_map_equal(expected, tree)
 
@@ -152,17 +159,17 @@ class SassTestCase(BaseTestCase):
         assert re.match(r'^\d+\.\d+\.\d+$', sass.__version__)
 
     def test_output_styles(self):
-        assert isinstance(sass.OUTPUT_STYLES, collections.Mapping)
+        assert isinstance(sass.OUTPUT_STYLES, collections_abc.Mapping)
         assert 'nested' in sass.OUTPUT_STYLES
 
     def test_and_join(self):
         self.assertEqual(
             'Korea, Japan, China, and Taiwan',
-            sass.and_join(['Korea', 'Japan', 'China', 'Taiwan'])
+            sass.and_join(['Korea', 'Japan', 'China', 'Taiwan']),
         )
         self.assertEqual(
             'Korea, and Japan',
-            sass.and_join(['Korea', 'Japan'])
+            sass.and_join(['Korea', 'Japan']),
         )
         assert 'Korea' == sass.and_join(['Korea'])
         assert '' == sass.and_join([])
@@ -177,31 +184,49 @@ class CompileTestCase(BaseTestCase):
         self.assertRaises(TypeError, sass.compile, 'a { color: blue; }')
 
     def test_compile_exclusive_arguments(self):
-        self.assertRaises(TypeError, sass.compile,
-                          string='a { color: blue; }', filename='test/a.scss')
-        self.assertRaises(TypeError, sass.compile,
-                          string='a { color: blue; }', dirname='test/')
-        self.assertRaises(TypeError,  sass.compile,
-                          filename='test/a.scss', dirname='test/')
+        self.assertRaises(
+            TypeError, sass.compile,
+            string='a { color: blue; }', filename='test/a.scss',
+        )
+        self.assertRaises(
+            TypeError, sass.compile,
+            string='a { color: blue; }', dirname='test/',
+        )
+        self.assertRaises(
+            TypeError,  sass.compile,
+            filename='test/a.scss', dirname='test/',
+        )
 
     def test_compile_invalid_output_style(self):
-        self.assertRaises(TypeError, sass.compile,
-                          string='a { color: blue; }',
-                          output_style=['compact'])
-        self.assertRaises(TypeError,  sass.compile,
-                          string='a { color: blue; }', output_style=123j)
-        self.assertRaises(ValueError,  sass.compile,
-                          string='a { color: blue; }', output_style='invalid')
+        self.assertRaises(
+            TypeError, sass.compile,
+            string='a { color: blue; }',
+            output_style=['compact'],
+        )
+        self.assertRaises(
+            TypeError,  sass.compile,
+            string='a { color: blue; }', output_style=123j,
+        )
+        self.assertRaises(
+            ValueError,  sass.compile,
+            string='a { color: blue; }', output_style='invalid',
+        )
 
     def test_compile_invalid_source_comments(self):
-        self.assertRaises(TypeError, sass.compile,
-                          string='a { color: blue; }',
-                          source_comments=['line_numbers'])
-        self.assertRaises(TypeError,  sass.compile,
-                          string='a { color: blue; }', source_comments=123j)
-        self.assertRaises(TypeError,  sass.compile,
-                          string='a { color: blue; }',
-                          source_comments='invalid')
+        self.assertRaises(
+            TypeError, sass.compile,
+            string='a { color: blue; }',
+            source_comments=['line_numbers'],
+        )
+        self.assertRaises(
+            TypeError,  sass.compile,
+            string='a { color: blue; }', source_comments=123j,
+        )
+        self.assertRaises(
+            TypeError,  sass.compile,
+            string='a { color: blue; }',
+            source_comments='invalid',
+        )
 
     def test_compile_disallows_arbitrary_arguments(self):
         for args in (
@@ -219,10 +244,12 @@ class CompileTestCase(BaseTestCase):
     def test_compile_string(self):
         actual = sass.compile(string='a { b { color: blue; } }')
         assert actual == 'a b {\n  color: blue; }\n'
-        commented = sass.compile(string='''a {
+        commented = sass.compile(
+            string='''a {
             b { color: blue; }
             color: red;
-        }''', source_comments=True)
+        }''', source_comments=True,
+        )
         assert commented == '''/* line 1, stdin */
 a {
   color: red; }
@@ -238,19 +265,25 @@ a {
 
 /* 유니코드 */
 ''',
-            actual
+            actual,
+        )
+        self.assertRaises(
+            sass.CompileError, sass.compile,
+            string='a { b { color: blue; }',
         )
-        self.assertRaises(sass.CompileError, sass.compile,
-                          string='a { b { color: blue; }')
         # sass.CompileError should be a subtype of ValueError
-        self.assertRaises(ValueError, sass.compile,
-                          string='a { b { color: blue; }')
+        self.assertRaises(
+            ValueError, sass.compile,
+            string='a { b { color: blue; }',
+        )
         self.assertRaises(TypeError, sass.compile, string=1234)
         self.assertRaises(TypeError, sass.compile, string=[])
 
     def test_compile_string_sass_style(self):
-        actual = sass.compile(string='a\n\tb\n\t\tcolor: blue;',
-                              indented=True)
+        actual = sass.compile(
+            string='a\n\tb\n\t\tcolor: blue;',
+            indented=True,
+        )
         assert actual == 'a b {\n  color: blue; }\n'
 
     def test_importer_one_arg(self):
@@ -322,7 +355,7 @@ a {
                     json.dumps({
                         "version": 3,
                         "sources": [
-                            path + ".db"
+                            path + ".db",
                         ],
                         "mappings": ";AAAA,CAAC,CAAC;EAAE,KAAK,EAAE,GAAI,GAAI",
                     }),
@@ -340,7 +373,7 @@ a {
 
     def test_importers_raises_exception(self):
         def importer(path):
-            raise ValueError('Bad path: {0}'.format(path))
+            raise ValueError('Bad path: {}'.format(path))
 
         with assert_raises_compile_error(RegexMatcher(
                 r'^Error: \n'
@@ -349,7 +382,7 @@ a {
                 r'ValueError: Bad path: hi\n'
                 r'        on line 1 of stdin\n'
                 r'>> @import "hi";\n'
-                r'   --------\^\n'
+                r'   --------\^\n',
         )):
             sass.compile(string='@import "hi";', importers=((0, importer),))
 
@@ -365,7 +398,7 @@ a {
                 r'length \(1, 2, 3\) but got 0: \(\)\n'
                 r'        on line 1 of stdin\n'
                 r'>> @import "hi";\n'
-                r'   --------\^\n'
+                r'   --------\^\n',
         )):
             sass.compile(string='@import "hi";', importers=((0, importer),))
 
@@ -381,7 +414,7 @@ a {
                 r"length \(1, 2, 3\) but got 4: \('a', 'b', 'c', 'd'\)\n"
                 r'        on line 1 of stdin\n'
                 r'>> @import "hi";\n'
-                r'   --------\^\n'
+                r'   --------\^\n',
         )):
             sass.compile(string='@import "hi";', importers=((0, importer),))
 
@@ -393,10 +426,12 @@ a {
         expected = sass.compile(string=source, source_comments=True)
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter('always')
-            actual = sass.compile(string=source,
-                                  source_comments='line_numbers')
+            actual = sass.compile(
+                string=source,
+                source_comments='line_numbers',
+            )
             assert len(w) == 1
-            assert issubclass(w[-1].category, DeprecationWarning)
+            assert issubclass(w[-1].category, FutureWarning)
         assert expected == actual
 
     def test_compile_filename(self):
@@ -408,8 +443,10 @@ a {
         assert D_EXPECTED_CSS == actual
         actual = sass.compile(filename='test/e.scss')
         assert actual == E_EXPECTED_CSS
-        self.assertRaises(IOError, sass.compile,
-                          filename='test/not-exist.sass')
+        self.assertRaises(
+            IOError, sass.compile,
+            filename='test/not-exist.sass',
+        )
         self.assertRaises(TypeError, sass.compile, filename=1234)
         self.assertRaises(TypeError, sass.compile, filename=[])
 
@@ -417,7 +454,7 @@ a {
         filename = 'test/a.scss'
         actual, source_map = sass.compile(
             filename=filename,
-            source_map_filename='a.scss.css.map'
+            source_map_filename='a.scss.css.map',
         )
         assert A_EXPECTED_CSS_WITH_MAP == actual
         self.assert_source_map_equal(A_EXPECTED_MAP, source_map)
@@ -426,17 +463,17 @@ a {
         filename = 'test/a.scss'
         expected, expected_map = sass.compile(
             filename=filename,
-            source_map_filename='a.scss.css.map'
+            source_map_filename='a.scss.css.map',
         )
         with warnings.catch_warnings(record=True) as w:
             warnings.simplefilter('always')
             actual, actual_map = sass.compile(
                 filename=filename,
                 source_comments='map',
-                source_map_filename='a.scss.css.map'
+                source_map_filename='a.scss.css.map',
             )
             assert len(w) == 1
-            assert issubclass(w[-1].category, DeprecationWarning)
+            assert issubclass(w[-1].category, FutureWarning)
         assert expected == actual
         self.assert_source_map_equal(expected_map, actual_map)
 
@@ -447,23 +484,27 @@ a {
         assert actual == G_EXPECTED_CSS_WITH_PRECISION_8
 
     def test_regression_issue_2(self):
-        actual = sass.compile(string='''
+        actual = sass.compile(
+            string='''
             @media (min-width: 980px) {
                 a {
                     color: red;
                 }
             }
-        ''')
+        ''',
+        )
         normalized = re.sub(r'\s+', '', actual)
         assert normalized == '@media(min-width:980px){a{color:red;}}'
 
     def test_regression_issue_11(self):
-        actual = sass.compile(string='''
+        actual = sass.compile(
+            string='''
             $foo: 3;
             @media (max-width: $foo) {
                 body { color: black; }
             }
-        ''')
+        ''',
+        )
         normalized = re.sub(r'\s+', '', actual)
         assert normalized == '@media(max-width:3){body{color:black;}}'
 
@@ -515,7 +556,7 @@ class BuilderTestCase(BaseTestCase):
         assert E_EXPECTED_CSS == css
         self.assertEqual(
             os.path.join('subdir', 'recur.scss.css'),
-            result_files[os.path.join('subdir', 'recur.scss')]
+            result_files[os.path.join('subdir', 'recur.scss')],
         )
         with io.open(
             os.path.join(css_path, 'g.scss.css'), encoding='UTF-8',
@@ -524,7 +565,7 @@ class BuilderTestCase(BaseTestCase):
         assert G_EXPECTED_CSS == css
         self.assertEqual(
             os.path.join('subdir', 'recur.scss.css'),
-            result_files[os.path.join('subdir', 'recur.scss')]
+            result_files[os.path.join('subdir', 'recur.scss')],
         )
         with io.open(
             os.path.join(css_path, 'subdir', 'recur.scss.css'),
@@ -535,27 +576,40 @@ class BuilderTestCase(BaseTestCase):
 
     def test_output_style(self):
         css_path = self.css_path
-        result_files = build_directory(self.sass_path, css_path,
-                                       output_style='compressed')
+        result_files = build_directory(
+            self.sass_path, css_path,
+            output_style='compressed',
+        )
         assert len(result_files) == 7
         assert 'a.scss.css' == result_files['a.scss']
         with io.open(
             os.path.join(css_path, 'a.scss.css'), encoding='UTF-8',
         ) as f:
             css = f.read()
-        self.assertEqual('body{background-color:green}body a{color:blue}\n',
-                         css)
+        self.assertEqual(
+            'body{background-color:green}body a{color:blue}\n',
+            css,
+        )
 
 
 class ManifestTestCase(BaseTestCase):
 
     def test_normalize_manifests(self):
-        manifests = Manifest.normalize_manifests({
-            'package': 'sass/path',
-            'package.name': ('sass/path', 'css/path'),
-            'package.name2': Manifest('sass/path', 'css/path')
-        })
-        assert len(manifests) == 3
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            manifests = Manifest.normalize_manifests({
+                'package': 'sass/path',
+                'package.name': ('sass/path', 'css/path'),
+                'package.name2': Manifest('sass/path', 'css/path'),
+                'package.name3': {
+                    'sass_path': 'sass/path',
+                    'css_path': 'css/path',
+                    'strip_extension': True,
+                },
+            })
+            assert len(w) == 3
+            assert all(issubclass(x.category, FutureWarning) for x in w)
+        assert len(manifests) == 4
         assert isinstance(manifests['package'], Manifest)
         assert manifests['package'].sass_path == 'sass/path'
         assert manifests['package'].css_path == 'sass/path'
@@ -565,6 +619,10 @@ class ManifestTestCase(BaseTestCase):
         assert isinstance(manifests['package.name2'], Manifest)
         assert manifests['package.name2'].sass_path == 'sass/path'
         assert manifests['package.name2'].css_path == 'css/path'
+        assert isinstance(manifests['package.name3'], Manifest)
+        assert manifests['package.name3'].sass_path == 'sass/path'
+        assert manifests['package.name3'].css_path == 'css/path'
+        assert manifests['package.name3'].strip_extension is True
 
     def test_build_one(self):
         with tempdir() as d:
@@ -577,7 +635,12 @@ class ManifestTestCase(BaseTestCase):
                 return s.replace('SOURCE', test_source_path(name))
 
             shutil.copytree('test', src_path)
-            m = Manifest(sass_path='test', css_path='css')
+            with warnings.catch_warnings(record=True) as w:
+                warnings.simplefilter('always')
+                m = Manifest(sass_path='test', css_path='css')
+                assert len(w) == 1
+                assert issubclass(w[-1].category, FutureWarning)
+
             m.build_one(d, 'a.scss')
             with open(os.path.join(d, 'css', 'a.scss.css')) as f:
                 assert A_EXPECTED_CSS == f.read()
@@ -600,7 +663,7 @@ class ManifestTestCase(BaseTestCase):
                         'GAChB'
                     ),
                 },
-                os.path.join(d, 'css', 'b.scss.css.map')
+                os.path.join(d, 'css', 'b.scss.css.map'),
             )
             m.build_one(d, 'd.scss', source_map=True)
             with io.open(
@@ -622,10 +685,30 @@ class ManifestTestCase(BaseTestCase):
                         'GAC7B'
                     ),
                 },
-                os.path.join(d, 'css', 'd.scss.css.map')
+                os.path.join(d, 'css', 'd.scss.css.map'),
             )
 
 
+def test_manifest_build_one_strip_extension(tmpdir):
+    src = tmpdir.join('test').ensure_dir()
+    src.join('a.scss').write('a{b: c;}')
+
+    m = Manifest(sass_path='test', css_path='css', strip_extension=True)
+    m.build_one(str(tmpdir), 'a.scss')
+
+    assert tmpdir.join('css/a.css').read() == 'a {\n  b: c; }\n'
+
+
+def test_manifest_build_strip_extension(tmpdir):
+    src = tmpdir.join('test').ensure_dir()
+    src.join('x.scss').write('a{b: c;}')
+
+    m = Manifest(sass_path='test', css_path='css', strip_extension=True)
+    m.build(package_dir=str(tmpdir))
+
+    assert tmpdir.join('css/x.css').read() == 'a {\n  b: c; }\n'
+
+
 class WsgiTestCase(BaseTestCase):
 
     @staticmethod
@@ -637,9 +720,15 @@ class WsgiTestCase(BaseTestCase):
         with tempdir() as css_dir:
             src_dir = os.path.join(css_dir, 'src')
             shutil.copytree('test', src_dir)
-            app = SassMiddleware(self.sample_wsgi_app, {
-                __name__: (src_dir, css_dir, '/static')
-            })
+            with warnings.catch_warnings(record=True) as w:
+                warnings.simplefilter('always')
+                app = SassMiddleware(
+                    self.sample_wsgi_app, {
+                        __name__: (src_dir, css_dir, '/static'),
+                    },
+                )
+                assert len(w) == 1
+                assert issubclass(w[-1].category, FutureWarning)
             client = Client(app, Response)
             r = client.get('/asdf')
             assert r.status_code == 200
@@ -678,7 +767,7 @@ class DistutilsTestCase(BaseTestCase):
         testpkg_path = os.path.join(os.path.dirname(__file__), 'testpkg')
         return subprocess.call(
             [sys.executable, 'setup.py', 'build_sass'] + list(args),
-            cwd=os.path.abspath(testpkg_path)
+            cwd=os.path.abspath(testpkg_path),
         )
 
     def test_build_sass(self):
@@ -686,12 +775,12 @@ class DistutilsTestCase(BaseTestCase):
         assert rv == 0
         self.assertEqual(
             ['a.scss.css'],
-            list(map(os.path.basename, self.list_built_css()))
+            list(map(os.path.basename, self.list_built_css())),
         )
         with open(self.css_path('a.scss.css')) as f:
             self.assertEqual(
                 'p a {\n  color: red; }\n\np b {\n  color: blue; }\n',
-                f.read()
+                f.read(),
             )
 
     def test_output_style(self):
@@ -700,7 +789,7 @@ class DistutilsTestCase(BaseTestCase):
         with open(self.css_path('a.scss.css')) as f:
             self.assertEqual(
                 'p a{color:red}p b{color:blue}\n',
-                f.read()
+                f.read(),
             )
 
 
@@ -711,7 +800,7 @@ class SasscTestCase(BaseTestCase):
         self.err = StringIO()
 
     def test_no_args(self):
-        exit_code = sassc.main(['sassc'], self.out, self.err)
+        exit_code = pysassc.main(['pysassc'], self.out, self.err)
         assert exit_code == 2
         err = self.err.getvalue()
         assert err.strip().endswith('error: too few arguments'), \
@@ -719,9 +808,9 @@ class SasscTestCase(BaseTestCase):
         assert '' == self.out.getvalue()
 
     def test_three_args(self):
-        exit_code = sassc.main(
-            ['sassc', 'a.scss', 'b.scss', 'c.scss'],
-            self.out, self.err
+        exit_code = pysassc.main(
+            ['pysassc', 'a.scss', 'b.scss', 'c.scss'],
+            self.out, self.err,
         )
         assert exit_code == 2
         err = self.err.getvalue()
@@ -729,18 +818,37 @@ class SasscTestCase(BaseTestCase):
             'actual error message is: ' + repr(err)
         assert self.out.getvalue() == ''
 
-    def test_sassc_stdout(self):
-        exit_code = sassc.main(['sassc', 'test/a.scss'], self.out, self.err)
+    def test_pysassc_stdout(self):
+        exit_code = pysassc.main(
+            ['pysassc', 'test/a.scss'],
+            self.out, self.err,
+        )
         assert exit_code == 0
         assert self.err.getvalue() == ''
         assert A_EXPECTED_CSS.strip() == self.out.getvalue().strip()
 
-    def test_sassc_output(self):
+    def test_sassc_stdout(self):
+        with warnings.catch_warnings(record=True) as w:
+            warnings.simplefilter('always')
+            exit_code = sassc.main(
+                ['sassc', 'test/a.scss'],
+                self.out, self.err,
+            )
+            assert len(w) == 1
+            assert issubclass(w[-1].category, FutureWarning)
+            assert 'use `pysassc`' in str(w[-1].message)
+        assert exit_code == 0
+        assert self.err.getvalue() == ''
+        assert A_EXPECTED_CSS.strip() == self.out.getvalue().strip()
+
+    def test_pysassc_output(self):
         fd, tmp = tempfile.mkstemp('.css')
         try:
             os.close(fd)
-            exit_code = sassc.main(['sassc', 'test/a.scss', tmp],
-                                   self.out, self.err)
+            exit_code = pysassc.main(
+                ['pysassc', 'test/a.scss', tmp],
+                self.out, self.err,
+            )
             assert exit_code == 0
             assert self.err.getvalue() == ''
             assert self.out.getvalue() == ''
@@ -749,12 +857,14 @@ class SasscTestCase(BaseTestCase):
         finally:
             os.remove(tmp)
 
-    def test_sassc_output_unicode(self):
+    def test_pysassc_output_unicode(self):
         fd, tmp = tempfile.mkstemp('.css')
         try:
             os.close(fd)
-            exit_code = sassc.main(['sassc', 'test/d.scss', tmp],
-                                   self.out, self.err)
+            exit_code = pysassc.main(
+                ['pysassc', 'test/d.scss', tmp],
+                self.out, self.err,
+            )
             assert exit_code == 0
             assert self.err.getvalue() == ''
             assert self.out.getvalue() == ''
@@ -763,13 +873,18 @@ class SasscTestCase(BaseTestCase):
         finally:
             os.remove(tmp)
 
-    def test_sassc_source_map_without_css_filename(self):
-        exit_code = sassc.main(['sassc', '-m', 'a.scss'], self.out, self.err)
+    def test_pysassc_source_map_without_css_filename(self):
+        exit_code = pysassc.main(
+            ['pysassc', '-m', 'a.scss'],
+            self.out, self.err,
+        )
         assert exit_code == 2
         err = self.err.getvalue()
-        assert err.strip().endswith('error: -m/-g/--sourcemap requires '
-                                    'the second argument, the output css '
-                                    'filename.'), \
+        assert err.strip().endswith(
+            'error: -m/-g/--sourcemap requires '
+            'the second argument, the output css '
+            'filename.',
+        ), \
             'actual error message is: ' + repr(err)
         assert self.out.getvalue() == ''
 
@@ -799,10 +914,14 @@ class CompileDirectoriesTest(unittest.TestCase):
             input_dir = os.path.join(tmpdir, 'input')
             output_dir = os.path.join(tmpdir, 'output')
             os.makedirs(os.path.join(input_dir, 'foo'))
-            write_file(os.path.join(input_dir, 'f1.scss'),
-                       'a { b { width: 100%; } }')
-            write_file(os.path.join(input_dir, 'foo/f2.scss'),
-                       'foo { width: 100%; }')
+            write_file(
+                os.path.join(input_dir, 'f1.scss'),
+                'a { b { width: 100%; } }',
+            )
+            write_file(
+                os.path.join(input_dir, 'foo/f2.scss'),
+                'foo { width: 100%; }',
+            )
             # Make sure we don't compile non-scss files
             write_file(os.path.join(input_dir, 'baz.txt'), 'Hello der')
 
@@ -813,8 +932,10 @@ class CompileDirectoriesTest(unittest.TestCase):
             assert os.path.exists(os.path.join(output_dir, 'foo/f2.css'))
             assert not os.path.exists(os.path.join(output_dir, 'baz.txt'))
 
-            contentsf1 = open(os.path.join(output_dir, 'f1.css')).read()
-            contentsf2 = open(os.path.join(output_dir, 'foo/f2.css')).read()
+            with open(os.path.join(output_dir, 'f1.css')) as f:
+                contentsf1 = f.read()
+            with open(os.path.join(output_dir, 'foo/f2.css')) as f:
+                contentsf2 = f.read()
             assert contentsf1 == 'a b {\n  width: 100%; }\n'
             assert contentsf2 == 'foo {\n  width: 100%; }\n'
 
@@ -852,7 +973,7 @@ class CompileDirectoriesTest(unittest.TestCase):
 
             with pytest.raises(sass.CompileError) as excinfo:
                 sass.compile(
-                    dirname=(input_dir, os.path.join(tmpdir, 'output'))
+                    dirname=(input_dir, os.path.join(tmpdir, 'output')),
                 )
             msg, = excinfo.value.args
             assert msg.startswith('Error: Invalid CSS after ')
@@ -861,10 +982,7 @@ class CompileDirectoriesTest(unittest.TestCase):
 class SassFunctionTest(unittest.TestCase):
 
     def test_from_lambda(self):
-        # Hack for https://gitlab.com/pycqa/flake8/issues/117
-        def noop(x):
-            return x
-        lambda_ = noop(lambda abc, d: None)  # pragma: no branch (lambda)
+        lambda_ = lambda abc, d: None  # pragma: no branch  # noqa: E731
         sf = sass.SassFunction.from_lambda('func_name', lambda_)
         assert 'func_name' == sf.name
         assert ('$abc', '$d') == sf.arguments
@@ -880,7 +998,7 @@ class SassFunctionTest(unittest.TestCase):
         sf = sass.SassFunction(  # pragma: no branch (doesn't run lambda)
             'func-name',
             ('$a', '$bc', '$d'),
-            lambda a, bc, d: None
+            lambda a, bc, d: None,
         )
         assert 'func-name($a, $bc, $d)' == sf.signature
         assert sf.signature == str(sf)
@@ -1132,7 +1250,7 @@ class CustomFunctionsTest(unittest.TestCase):
                 r'        on line 1 of stdin, in function `raises`\n'
                 r'        from line 1 of stdin\n'
                 r'>> a { content: raises\(\); }\n'
-                r'   -------------\^\n$'
+                r'   -------------\^\n$',
         )):
             compile_with_func('a { content: raises(); }')
 
@@ -1143,7 +1261,7 @@ class CustomFunctionsTest(unittest.TestCase):
                 '        on line 1 of stdin, in function `returns_warning`\n'
                 '        from line 1 of stdin\n'
                 '>> a { content: returns_warning(); }\n'
-                '   -------------^\n'
+                '   -------------^\n',
         ):
             compile_with_func('a { content: returns_warning(); }')
 
@@ -1154,7 +1272,7 @@ class CustomFunctionsTest(unittest.TestCase):
                 '        on line 1 of stdin, in function `returns_error`\n'
                 '        from line 1 of stdin\n'
                 '>> a { content: returns_error(); }\n'
-                '   -------------^\n'
+                '   -------------^\n',
         ):
             compile_with_func('a { content: returns_error(); }')
 
@@ -1176,7 +1294,7 @@ class CustomFunctionsTest(unittest.TestCase):
                 '        on line 1 of stdin, in function `returns_unknown`\n'
                 '        from line 1 of stdin\n'
                 '>> a { content: returns_unknown(); }\n'
-                '   -------------^\n'
+                '   -------------^\n',
         ):
             compile_with_func('a { content: returns_unknown(); }')
 
@@ -1237,7 +1355,7 @@ class CustomFunctionsTest(unittest.TestCase):
     def test_bracketed_list(self):
         self.assertEqual(
             compile_with_func('a { content: returns_bracketed_list(); }'),
-            'a{content:[hello ohai]}\n'
+            'a{content:[hello ohai]}\n',
         )
 
     def test_py_dict(self):
@@ -1339,9 +1457,9 @@ class CustomFunctionsTest(unittest.TestCase):
             compile_with_func(
                 'a{content: '
                 'map-get(nth(identity(((foo: bar), (baz: womp))), 1), foo)'
-                '}'
+                '}',
             ),
-            'a{content:bar}\n'
+            'a{content:bar}\n',
         )
 
     def test_map_with_map_key(self):
@@ -1363,7 +1481,7 @@ def test_stack_trace_formatting():
         'CompileError: Error: Invalid CSS after "a{☃": expected "{", was ""\n'
         '        on line 1 of stdin\n'
         '>> a{☃\n'
-        '   --^\n\n'
+        '   --^\n\n',
     )
 
 
@@ -1372,15 +1490,15 @@ def test_source_comments():
     assert out == '/* line 1, stdin */\na {\n  color: red; }\n'
 
 
-def test_sassc_sourcemap(tmpdir):
+def test_pysassc_sourcemap(tmpdir):
     src_file = tmpdir.join('src').ensure_dir().join('a.scss')
     out_file = tmpdir.join('a.scss.css')
     out_map_file = tmpdir.join('a.scss.css.map')
 
     src_file.write('.c { font-size: 5px + 5px; }')
 
-    exit_code = sassc.main([
-        'sassc', '-m', src_file.strpath, out_file.strpath,
+    exit_code = pysassc.main([
+        'pysassc', '-m', src_file.strpath, out_file.strpath,
     ])
     assert exit_code == 0
 
@@ -1419,11 +1537,13 @@ def test_import_no_css(tmpdir):
         sass.compile(filename=main_scss.strpath)
 
 
-@pytest.mark.parametrize('exts', [
-    ('.css',),
-    ['.css'],
-    ['.foobar', '.css'],
-])
+@pytest.mark.parametrize(
+    'exts', [
+        ('.css',),
+        ['.css'],
+        ['.foobar', '.css'],
+    ],
+)
 def test_import_css(exts, tmpdir):
     tmpdir.join('other.css').write('body {color: green}')
     main_scss = tmpdir.join('main.scss')
